==> aws-sdk-cpp-1.11.603-1-x86_64.pkg.tar.zst: usr/include/aws/cloudtrail-data/CloudTrailDataErrors.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once

#include <aws/core/client/AWSError.h>
#include <aws/core/client/CoreErrors.h>
#include <aws/cloudtrail-data/CloudTrailData_EXPORTS.h>

namespace Aws
{
namespace CloudTrailData
{
enum class CloudTrailDataErrors
{
  //From Core//
  //////////////////////////////////////////////////////////////////////////////////////////
  INCOMPLETE_SIGNATURE = 0,
  INTERNAL_FAILURE = 1,
  INVALID_ACTION = 2,
  INVALID_CLIENT_TOKEN_ID = 3,
  INVALID_PARAMETER_COMBINATION = 4,
  INVALID_QUERY_PARAMETER = 5,
  INVALID_PARAMETER_VALUE = 6,
  MISSING_ACTION = 7, // SDK should never allow
  MISSING_AUTHENTICATION_TOKEN = 8, // SDK should never allow
  MISSING_PARAMETER = 9, // SDK should never allow
  OPT_IN_REQUIRED = 10,
  REQUEST_EXPIRED = 11,
  SERVICE_UNAVAILABLE = 12,
  THROTTLING = 13,
  VALIDATION = 14,
  ACCESS_DENIED = 15,
  RESOURCE_NOT_FOUND = 16,
  UNRECOGNIZED_CLIENT = 17,
  MALFORMED_QUERY_STRING = 18,
  SLOW_DOWN = 19,
  REQUEST_TIME_TOO_SKEWED = 20,
  INVALID_SIGNATURE = 21,
  SIGNATURE_DOES_NOT_MATCH = 22,
  INVALID_ACCESS_KEY_ID = 23,
  REQUEST_TIMEOUT = 24,
  NETWORK_CONNECTION = 99,

  UNKNOWN = 100,
  ///////////////////////////////////////////////////////////////////////////////////////////

  CHANNEL_INSUFFICIENT_PERMISSION= static_cast<int>(Aws::Client::CoreErrors::SERVICE_EXTENSION_START_RANGE) + 1,
  CHANNEL_NOT_FOUND,
  CHANNEL_UNSUPPORTED_SCHEMA,
  DUPLICATED_AUDIT_EVENT_ID,
  INVALID_CHANNEL_A_R_N,
  UNSUPPORTED_OPERATION
};

class AWS_CLOUDTRAILDATA_API CloudTrailDataError : public Aws::Client::AWSError<CloudTrailDataErrors>
{
public:
  CloudTrailDataError() {}
  CloudTrailDataError(const Aws::Client::AWSError<Aws::Client::CoreErrors>& rhs) : Aws::Client::AWSError<CloudTrailDataErrors>(rhs) {}
  CloudTrailDataError(Aws::Client::AWSError<Aws::Client::CoreErrors>&& rhs) : Aws::Client::AWSError<CloudTrailDataErrors>(rhs) {}
  CloudTrailDataError(const Aws::Client::AWSError<CloudTrailDataErrors>& rhs) : Aws::Client::AWSError<CloudTrailDataErrors>(rhs) {}
  CloudTrailDataError(Aws::Client::AWSError<CloudTrailDataErrors>&& rhs) : Aws::Client::AWSError<CloudTrailDataErrors>(rhs) {}

  template <typename T>
  T GetModeledError();
};

namespace CloudTrailDataErrorMapper
{
  AWS_CLOUDTRAILDATA_API Aws::Client::AWSError<Aws::Client::CoreErrors> GetErrorForName(const char* errorName);
}

} // namespace CloudTrailData
} // namespace Aws

==> aws-sdk-cpp-1.11.739-1-x86_64.pkg.tar.zst: usr/include/aws/cloudtrail-data/CloudTrailDataErrors.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once

#include <aws/cloudtrail-data/CloudTrailData_EXPORTS.h>
#include <aws/core/client/AWSError.h>
#include <aws/core/client/CoreErrors.h>

namespace Aws {
namespace CloudTrailData {
enum class CloudTrailDataErrors {
  // From Core//
  //////////////////////////////////////////////////////////////////////////////////////////
  INCOMPLETE_SIGNATURE = 0,
  INTERNAL_FAILURE = 1,
  INVALID_ACTION = 2,
  INVALID_CLIENT_TOKEN_ID = 3,
  INVALID_PARAMETER_COMBINATION = 4,
  INVALID_QUERY_PARAMETER = 5,
  INVALID_PARAMETER_VALUE = 6,
  MISSING_ACTION = 7,                // SDK should never allow
  MISSING_AUTHENTICATION_TOKEN = 8,  // SDK should never allow
  MISSING_PARAMETER = 9,             // SDK should never allow
  OPT_IN_REQUIRED = 10,
  REQUEST_EXPIRED = 11,
  SERVICE_UNAVAILABLE = 12,
  THROTTLING = 13,
  VALIDATION = 14,
  ACCESS_DENIED = 15,
  RESOURCE_NOT_FOUND = 16,
  UNRECOGNIZED_CLIENT = 17,
  MALFORMED_QUERY_STRING = 18,
  SLOW_DOWN = 19,
  REQUEST_TIME_TOO_SKEWED = 20,
  INVALID_SIGNATURE = 21,
  SIGNATURE_DOES_NOT_MATCH = 22,
  INVALID_ACCESS_KEY_ID = 23,
  REQUEST_TIMEOUT = 24,
  NETWORK_CONNECTION = 99,

  UNKNOWN = 100,
  ///////////////////////////////////////////////////////////////////////////////////////////

  CHANNEL_INSUFFICIENT_PERMISSION = static_cast<int>(Aws::Client::CoreErrors::SERVICE_EXTENSION_START_RANGE) + 1,
  CHANNEL_NOT_FOUND,
  CHANNEL_UNSUPPORTED_SCHEMA,
  DUPLICATED_AUDIT_EVENT_ID,
  INVALID_CHANNEL_A_R_N,
  UNSUPPORTED_OPERATION
};

class AWS_CLOUDTRAILDATA_API CloudTrailDataError : public Aws::Client::AWSError<CloudTrailDataErrors> {
 public:
  CloudTrailDataError() {}
  CloudTrailDataError(const Aws::Client::AWSError<Aws::Client::CoreErrors>& rhs) : Aws::Client::AWSError<CloudTrailDataErrors>(rhs) {}
  CloudTrailDataError(Aws::Client::AWSError<Aws::Client::CoreErrors>&& rhs) : Aws::Client::AWSError<CloudTrailDataErrors>(rhs) {}
  CloudTrailDataError(const Aws::Client::AWSError<CloudTrailDataErrors>& rhs) : Aws::Client::AWSError<CloudTrailDataErrors>(rhs) {}
  CloudTrailDataError(Aws::Client::AWSError<CloudTrailDataErrors>&& rhs) : Aws::Client::AWSError<CloudTrailDataErrors>(rhs) {}

  template <typename T>
  T GetModeledError();
};

namespace CloudTrailDataErrorMapper {
AWS_CLOUDTRAILDATA_API Aws::Client::AWSError<Aws::Client::CoreErrors> GetErrorForName(const char* errorName);
}

}  // namespace CloudTrailData
}  // namespace Aws
